/*
 * ====================================================================
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2001 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in
 * the documentation and/or other materials provided with the
 * distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 * if any, must include the following acknowledgment:
 * "This product includes software developed by the
 * Apache Software Foundation (http://www.apache.org/)."
 * Alternately, this acknowledgment may appear in the software itself,
 * if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Apache" and "Apache Software Foundation" and
 * "Apache JMeter" must not be used to endorse or promote products
 * derived from this software without prior written permission. For
 * written permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 * "Apache JMeter", nor may "Apache" appear in their name, without
 * prior written permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */
package org.apache.jmeter.config;

import java.util.*;
import javax.swing.table.DefaultTableModel;

import org.apache.jmeter.gui.JMeterComponentModel;
import org.apache.jmeter.save.Saveable;

/************************************************************
 *  Title: Apache JMeter Description: Copyright: Copyright (c) 2000 Company:
 *  Apache Foundation
 *
 *@author     Michael Stover
 *@created    $Date: 2001/06/12 22:36:15 $
 *@version    1.0
 ***********************************************************/

public class Arguments extends DefaultTableModel implements JMeterComponentModel, Saveable
{
	private List args;
	private String name;
	private static String[] columnNames = {"Name", "Value"};

	/************************************************************
	 *  !ToDo (Constructor description)
	 ***********************************************************/
	public Arguments()
	{
	}

	/************************************************************
	 *  !ToDo (Method description)
	 *
	 *@param  newName  !ToDo (Parameter description)
	 ***********************************************************/
	public void setName(String newName)
	{
		name = newName;
	}

	/************************************************************
	 *  Sets the ValueAt attribute of the Arguments object
	 *
	 *@param  value  The new ValueAt value
	 *@param  row    The new ValueAt value
	 *@param  col    The new ValueAt value
	 ***********************************************************/
	public void setValueAt(Object value, int row, int col)
	{
		Argument arg = (Argument)args.get(row);
		if(col == 0)
		{
			arg.setName((String)value);
		}
		else
		{
			arg.setValue((String)value);
		}
	}

	/************************************************************
	 *  Gets the TagHandlerClass attribute of the Arguments object
	 *
	 *@return    The TagHandlerClass value
	 ***********************************************************/
	public Class getTagHandlerClass()
	{
		return org.apache.jmeter.save.handlers.ArgumentsHandler.class;
	}

	/************************************************************
	 *  !ToDoo (Method description)
	 *
	 *@return    !ToDo (Return description)
	 ***********************************************************/
	public String getClassLabel()
	{
		return "Argument List";
	}

	/************************************************************
	 *  !ToDoo (Method description)
	 *
	 *@return    !ToDo (Return description)
	 ***********************************************************/
	public Class getGuiClass()
	{
		return org.apache.jmeter.config.gui.ArgumentsPanel.class;
	}

	/************************************************************
	 *  !ToDoo (Method description)
	 *
	 *@return    !ToDo (Return description)
	 ***********************************************************/
	public String getName()
	{
		return name;
	}

	/************************************************************
	 *  !ToDoo (Method description)
	 *
	 *@return    !ToDo (Return description)
	 ***********************************************************/
	public boolean isEditable()
	{
		return true;
	}

	/************************************************************
	 *  !ToDoo (Method description)
	 *
	 *@return    !ToDo (Return description)
	 ***********************************************************/
	public Collection getAddList()
	{
		return null;
	}

	/************************************************************
	 *  required by table model interface
	 *
	 *@return    !ToDo (Return description)
	 ***********************************************************/
	public int getRowCount()
	{
		if(args == null)
		{
			args = new ArrayList();
		}
		return args.size();
	}

	/************************************************************
	 *  required by table model interface
	 *
	 *@return    !ToDo (Return description)
	 ***********************************************************/
	public int getColumnCount()
	{
		return 2;
	}

	/************************************************************
	 *  required by table model interface
	 *
	 *@param  column  !ToDo (Parameter description)
	 *@return         !ToDo (Return description)
	 ***********************************************************/
	public String getColumnName(int column)
	{
		return columnNames[column];
	}

	/************************************************************
	 *  required by table model interface
	 *
	 *@param  column  !ToDo (Parameter description)
	 *@return         !ToDo (Return description)
	 ***********************************************************/
	public Class getColumnClass(int column)
	{
		return java.lang.String.class;
	}

	/************************************************************
	 *  required by table model interface
	 *
	 *@param  row     !ToDo (Parameter description)
	 *@param  column  !ToDo (Parameter description)
	 *@return         !ToDo (Return description)
	 ***********************************************************/
	public Object getValueAt(int row, int column)
	{
		try
		{
			Argument arg = (Argument)args.get(row);
			if(column == 0)
			{
				return arg.getName();
			}
			else
			{
				return arg.getValue();
			}
		}
		catch(Exception ex)
		{
		}
		return null;
	}

	/************************************************************
	 *  Description of the Method
	 ***********************************************************/
	public void uncompile()
	{
	}

	/************************************************************
	 *  Description of the Method
	 *
	 *@param  row  Description of Parameter
	 ***********************************************************/
	public void removeRow(int row)
	{
		args.remove(row);
	}

	/************************************************************
	 *  Adds a feature to the NewRow attribute of the Arguments object
	 ***********************************************************/
	public void addNewRow()
	{
		args.add(new Argument(null, null));
	}

	/************************************************************
	 *  !ToDo
	 *
	 *@param  name   !ToDo
	 *@param  value  !ToDo
	 ***********************************************************/
	public void addArgument(String name, Object value)
	{
		args.add(new Argument(name, value));
	}

	/************************************************************
	 *  !ToDo (Method description)
	 *
	 *@return    !ToDo (Return description)
	 ***********************************************************/
	public Iterator iterator()
	{
		return args.iterator();
	}

	public String toString()
	{
		StringBuffer str = new StringBuffer();
		Iterator iter = args.iterator();
		while (iter.hasNext())
		{
			Argument arg = (Argument)iter.next();
			str.append(arg.name+"="+arg.value);
			if(iter.hasNext())
			{
				str.append("&");
			}
		}
		return str.toString();
	}

}
