/*
 * ====================================================================
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2001 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in
 * the documentation and/or other materials provided with the
 * distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 * if any, must include the following acknowledgment:
 * "This product includes software developed by the
 * Apache Software Foundation (http://www.apache.org/)."
 * Alternately, this acknowledgment may appear in the software itself,
 * if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Apache" and "Apache Software Foundation" and
 * "Apache JMeter" must not be used to endorse or promote products
 * derived from this software without prior written permission. For
 * written permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 * "Apache JMeter", nor may "Apache" appear in their name, without
 * prior written permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */
 package org.apache.jmeter.gui;

import javax.swing.*;
import java.util.*;

import org.apache.jmeter.util.*;
import org.apache.jmeter.gui.JMeterComponentModel;
import org.apache.jmeter.gui.action.ActionRouter;

/************************************************************
 *  Title: JMeter Description: Copyright: Copyright (c) 2000 Company: Apache
 *
 *@author     Michael Stover
 *@created    $Date: 2001/03/17 22:25:45 $
 *@version    1.0
 ***********************************************************/

public class MenuFactory
{
	private static JMenu timerMenu;
	private static JMenu controllerMenu;
	private static JMenu listenerMenu;
	private static JMenu configMenu;
	private static Set elementsToSkip = new HashSet();
	static
	{
		String[] classesToSkip = JMeterUtils.split(
					JMeterUtils.getPropDefault("not_in_menu",""),",");
		for (int i = 0; i < classesToSkip.length; i++)
		{
			elementsToSkip.add(classesToSkip[i]);
		}
	}


	/************************************************************
	 *  !ToDo (Constructor description)
	 ***********************************************************/
	public MenuFactory()
	{
	}

	/************************************************************
	 *  !ToDoo (Method description)
	 *
	 *@return    !ToDo (Return description)
	 ***********************************************************/
	public static synchronized JMenu getTimerMenu()
	{
		if (timerMenu == null)
		{
			timerMenu = createMenu(
					new Class[]{org.apache.jmeter.timers.Timer.class},"Timer",null);
			setEnabled(timerMenu);
		}
		return timerMenu;
	}

	private static void setEnabled(JMenu menu)
	{
		if(menu.getSubElements().length == 0)
			menu.setEnabled(false);
	}

	/************************************************************
	 *  !ToDoo (Method description)
	 *
	 *@return    !ToDo (Return description)
	 ***********************************************************/
	public static synchronized JMenu getListenerMenu()
	{
		if (listenerMenu == null)
		{
			Set skip = new HashSet();
			skip.add("org.apache.jmeter.threads.ThreadGroup");
			listenerMenu = createMenu(
					new Class[]{org.apache.jmeter.samplers.SampleListener.class},"Listener",
					skip);
			setEnabled(listenerMenu);
		}
		return listenerMenu;
	}

	/************************************************************
	 *  !ToDoo (Method description)
	 *
	 *@return    !ToDo (Return description)
	 ***********************************************************/
	public static synchronized JMenu getControllerMenu()
	{
		if (controllerMenu == null)
		{
			Set skip = new HashSet();
			controllerMenu = createMenu(
					new Class[]{org.apache.jmeter.control.SamplerController.class},"Controller",
					null);
			setEnabled(controllerMenu);
		}
		return controllerMenu;
	}

	/************************************************************
	 *  !ToDoo (Method description)
	 *
	 *@return    !ToDo (Return description)
	 ***********************************************************/
	public static synchronized JMenu getConfigElementMenu()
	{
		if (configMenu == null)
		{
			Set skip = new HashSet();
			configMenu = createMenu(new Class[]{org.apache.jmeter.config.ConfigElement.class},
							 "Config Element",null);
			setEnabled(configMenu);
		}
		return configMenu;
	}

	private static String getClassLabel(String className)
	{
		String label;
		try
		{
			label = ((JMeterComponentModel)Class.forName(className).newInstance()).getClassLabel();
		}
		catch (Throwable e)
		{
			label = className;
		}
		return label;
	}

	private static JMenu createMenu(Class[] classes,String menuName,
			Set skip)
	{
		JMenu menu = new JMenu();
		try
		{
			List listClasses = ClassFinder.findClassesThatExtend(classes);
			menu = new JMenu(menuName);
			Collections.sort((List)listClasses);
			Iterator iter = listClasses.iterator();
			while (iter.hasNext())
			{
				String item = (String)iter.next();
				if((skip == null || !skip.contains(item)) && !elementsToSkip.contains(item))
				{
					JMenuItem mItem = new JMenuItem(getClassLabel(item));
					mItem.addActionListener(ActionRouter.getInstance());
					menu.add(mItem);
				}

			}
		}
		catch (Exception ex)
		{
			ex.printStackTrace();
		}
		return menu;
	}

}
