/*
 * ====================================================================
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2001 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in
 * the documentation and/or other materials provided with the
 * distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 * if any, must include the following acknowledgment:
 * "This product includes software developed by the
 * Apache Software Foundation (http://www.apache.org/)."
 * Alternately, this acknowledgment may appear in the software itself,
 * if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Apache" and "Apache Software Foundation" and
 * "Apache JMeter" must not be used to endorse or promote products
 * derived from this software without prior written permission. For
 * written permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 * "Apache JMeter", nor may "Apache" appear in their name, without
 * prior written permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */
 package org.apache.jmeter.protocol.ftp.sampler;

import java.sql.*;
import org.apache.jmeter.util.JMeterUtils;
import org.apache.jmeter.config.*;
import org.apache.jmeter.protocol.ftp.config.*;
import org.apache.jmeter.samplers.Sampler;
import org.apache.jmeter.samplers.SampleResult;
import org.apache.jmeter.samplers.Entry;

/************************************************************
 *  A sampler which understands FTP file requests
 *
 *@author     $Author: mstover1 $
 *@created    $Date: 2001/03/17 22:25:48 $
 *@version    $Revision: 1.6 $
 ***********************************************************/

public class FTPSampler implements Sampler
{

	/************************************************************
	 *  !ToDo (Constructor description)
	 ***********************************************************/
	public FTPSampler()
	{
	}

	/************************************************************
	 *  !ToDo (Method description)
	 *
	 *@param  e  !ToDo (Parameter description)
	 *@return    !ToDo (Return description)
	 ***********************************************************/
	public SampleResult sample(Entry e)
	{
		SampleResult res = new SampleResult();
		Connection con = null;
		ResultSet rs = null;
		Statement stmt = null;
		FtpConfig ftpConfig = (FtpConfig)e.getConfigElement(FtpConfig.class);
		LoginConfig loginConfig = (LoginConfig)e.getConfigElement(LoginConfig.class);
		long start = System.currentTimeMillis();
		try
		{
			System.out.println("Connecting to "+ftpConfig.getServer()+" trying to get "+ftpConfig.getFilename());
			System.out.println("Username = "+loginConfig.getUsername());
			FtpClient ftp = new FtpClient();
			ftp.connect(ftpConfig.getServer(), loginConfig.getUsername(),
					loginConfig.getPassword());
			ftp.setPassive(true);
			String s = ftp.get(ftpConfig.getFilename());
			ftp.disconnect();
			//System.out.println(s);
		}
		catch (Exception ex)
		{
			//System.out.println(ex.toString());
		}
		// Calculate response time
		long end = System.currentTimeMillis();

		res.setTime(end - start);
		return res;
	}
}

