/*
 * ====================================================================
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2001 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in
 * the documentation and/or other materials provided with the
 * distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 * if any, must include the following acknowledgment:
 * "This product includes software developed by the
 * Apache Software Foundation (http://www.apache.org/)."
 * Alternately, this acknowledgment may appear in the software itself,
 * if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Apache" and "Apache Software Foundation" and
 * "Apache JMeter" must not be used to endorse or promote products
 * derived from this software without prior written permission. For
 * written permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 * "Apache JMeter", nor may "Apache" appear in their name, without
 * prior written permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */
 package org.apache.jmeter.protocol.http.gui;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.table.*;
import java.io.*;
import java.awt.*;
import java.awt.event.*;
import org.apache.jmeter.util.JMeterUtils;
import org.apache.jmeter.protocol.http.control.*;
import org.apache.jmeter.gui.*;

/************************************************************
 *  Handles input for determining if authentication services are required for a
 *  Sampler. It also understands how to get AuthManagers for the files that the
 *  user selects.
 *
 *@author     $Author: mstover1 $
 *@created    $Date: 2001/03/17 22:25:50 $
 *@version    $Revision: 1.6 $
 ***********************************************************/
public class AuthPanel extends JPanel implements ModelSupported
{

	/************************************************************
	 *  The authentication manager for this object
	 ***********************************************************/
	AuthManager manager = new AuthManager();

	/************************************************************
	 *  A table to show the authentication information
	 ***********************************************************/
	JTable authTable;
	private NamePanel namePanel;

	/************************************************************
	 *  Default Constructor
	 ***********************************************************/
	public AuthPanel()
	{
	}

	public void setModel(Object model)
	{
		manager = (AuthManager)model;
		init();
	}

	public void updateGui()
	{
		manager.fireTableDataChanged();
		namePanel.updateGui();
	}

	/************************************************************
	 *  Retrieves the AuthManager for the currently selected file.
	 *
	 *@return     !ToDo (Return description)
	 *@returns    an AuthManager for the current file, or null if: a file is not
	 *      selected or that file cannot be read.
	 ***********************************************************/
	public AuthManager getAuthMgr()
	{
		return manager;
	}

	/************************************************************
	 *  Shows the main authentication panel for this object
	 ***********************************************************/
	public void init()
	{
		this.setLayout(new VerticalLayout());
		namePanel = new NamePanel(manager);
		this.add(namePanel);
		authTable = new JTable(manager);
		authTable.setCellSelectionEnabled(false);
		authTable.setRowSelectionAllowed(true);
		authTable.setColumnSelectionAllowed(false);
		authTable.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);

		JPanel main = new JPanel();
		main.setLayout(new BorderLayout());

		JScrollPane scroller = new JScrollPane(authTable);
		JTableHeader tableHeader = authTable.getTableHeader();
		scroller.setColumnHeaderView(tableHeader);
		main.add(scroller);

		JButton add = new JButton("Add");
		JButton edit = new JButton("Edit");
		JButton delete = new JButton("Delete");
		JButton load = new JButton("Load");
		JButton save = new JButton("Save");
		Dimension d = delete.getPreferredSize();
		add.setPreferredSize(d);
		edit.setPreferredSize(d);
		load.setPreferredSize(d);
		save.setPreferredSize(d);

		add.addActionListener(
			new ActionListener()
			{
				/************************************************************
				 *  !ToDo (Method description)
				 *
				 *@param  e  !ToDo (Parameter description)
				 ***********************************************************/
				public void actionPerformed(ActionEvent e)
				{
					final JDialog addDialog = new JDialog();
					addDialog.setSize(300, 150);

					JPanel _main = new JPanel();
					GridBagLayout g = new GridBagLayout();
					_main.setLayout(g);
					GridBagConstraints c = new GridBagConstraints();
					c.fill = c.BOTH;
					c.gridwidth = 1;
					c.gridheight = 1;
					c.gridx = 1;
					c.gridy = 1;
					JLabel urlLabel = new JLabel("Base URL:");
					g.setConstraints(urlLabel, c);

					_main.add(urlLabel);
					final JTextField nameField = new JTextField(20);
					c.gridx = 2;
					c.gridy = 1;
					g.setConstraints(nameField, c);
					_main.add(nameField);
					JLabel usernameLabel = new JLabel("Username:");
					c.gridx = 1;
					c.gridy = 2;
					g.setConstraints(usernameLabel, c);
					_main.add(usernameLabel);
					final JTextField usernameField = new JTextField(20);
					c.gridx = 2;
					c.gridy = 2;
					g.setConstraints(usernameField, c);
					_main.add(usernameField);
					JLabel passwordLabel = new JLabel("Password:");
					c.gridx = 1;
					c.gridy = 3;
					g.setConstraints(passwordLabel, c);
					_main.add(passwordLabel);
					final JPasswordField passwordField = new JPasswordField(20);
					c.gridx = 2;
					c.gridy = 3;
					g.setConstraints(passwordField, c);
					_main.add(passwordField);
					JButton ok = new JButton("Ok");
					JButton cancel = new JButton("Cancel");
					ok.setPreferredSize(cancel.getPreferredSize());
					ok.addActionListener(
						new ActionListener()
						{
							/************************************************************
							 *  !ToDo (Method description)
							 *
							 *@param  ev  !ToDo (Parameter description)
							 ***********************************************************/
							public void actionPerformed(ActionEvent ev)
							{
								manager.set(-1, nameField.getText(), usernameField.getText(), new String(passwordField.getPassword()));
								addDialog.dispose();
							}
						});
					cancel.addActionListener(
						new ActionListener()
						{
							/************************************************************
							 *  !ToDo (Method description)
							 *
							 *@param  ev  !ToDo (Parameter description)
							 ***********************************************************/
							public void actionPerformed(ActionEvent ev)
							{
								addDialog.dispose();
							}
						});
					c.fill = c.NONE;
					c.anchor = c.EAST;
					c.gridx = 1;
					c.gridy = 4;
					g.setConstraints(ok, c);
					_main.add(ok);
					c.anchor = c.WEST;
					c.gridx = 2;
					c.gridy = 4;
					g.setConstraints(cancel, c);
					_main.add(cancel);
					addDialog.getContentPane().add(_main);
					addDialog.show();
				}
			});
		edit.addActionListener(
			new ActionListener()
			{
				/************************************************************
				 *  !ToDo (Method description)
				 *
				 *@param  e  !ToDo (Parameter description)
				 ***********************************************************/
				public void actionPerformed(ActionEvent e)
				{
					final int row = authTable.getSelectedRow();
					if (row >= 0)
					{
						Authorization auth = manager.get(row);
						final JDialog addDialog = new JDialog();
						addDialog.setSize(300, 150);

						JPanel _main = new JPanel();
						GridBagLayout g = new GridBagLayout();

						_main.setLayout(g);
						GridBagConstraints c = new GridBagConstraints();
						c.fill = c.BOTH;
						c.gridwidth = 1;
						c.gridheight = 1;
						c.gridx = 1;
						c.gridy = 1;
						JLabel urlLabel = new JLabel("Base URL:");
						g.setConstraints(urlLabel, c);

						_main.add(urlLabel);
						final JTextField nameField = new JTextField(auth.getURL(), 20);
						c.gridx = 2;
						c.gridy = 1;
						g.setConstraints(nameField, c);
						_main.add(nameField);
						JLabel usernameLabel = new JLabel("Username:");
						c.gridx = 1;
						c.gridy = 2;
						g.setConstraints(usernameLabel, c);
						_main.add(usernameLabel);
						final JTextField usernameField = new JTextField(auth.getUser(), 20);
						c.gridx = 2;
						c.gridy = 2;
						g.setConstraints(usernameField, c);
						_main.add(usernameField);
						JLabel passwordLabel = new JLabel("Password:");
						c.gridx = 1;
						c.gridy = 3;
						g.setConstraints(passwordLabel, c);
						_main.add(passwordLabel);
						final JPasswordField passwordField = new JPasswordField(auth.getPass(), 20);
						c.gridx = 2;
						c.gridy = 3;
						g.setConstraints(passwordField, c);
						_main.add(passwordField);
						JButton ok = new JButton("Ok");
						JButton cancel = new JButton("Cancel");
						ok.setPreferredSize(cancel.getPreferredSize());
						ok.addActionListener(
							new ActionListener()
							{
								/************************************************************
								 *  !ToDo (Method description)
								 *
								 *@param  ev  !ToDo (Parameter description)
								 ***********************************************************/
								public void actionPerformed(ActionEvent ev)
								{
									manager.set(row, nameField.getText(), usernameField.getText(), new String(passwordField.getPassword()));
									addDialog.dispose();
								}
							});
						cancel.addActionListener(
							new ActionListener()
							{
								/************************************************************
								 *  !ToDo (Method description)
								 *
								 *@param  ev  !ToDo (Parameter description)
								 ***********************************************************/
								public void actionPerformed(ActionEvent ev)
								{
									addDialog.dispose();
								}
							});
						c.fill = c.NONE;
						c.anchor = c.EAST;
						c.gridx = 1;
						c.gridy = 4;
						g.setConstraints(ok, c);
						_main.add(ok);
						c.anchor = c.WEST;
						c.gridx = 2;
						c.gridy = 4;
						g.setConstraints(cancel, c);
						_main.add(cancel);
						addDialog.getContentPane().add(_main);
						addDialog.show();
					}
				}
			});
		delete.addActionListener(
			new ActionListener()
			{
				/************************************************************
				 *  !ToDo (Method description)
				 *
				 *@param  e  !ToDo (Parameter description)
				 ***********************************************************/
				public void actionPerformed(ActionEvent e)
				{
					int row = authTable.getSelectedRow();
					if (row >= 0)
					{
						manager.remove(row);
					}
				}
			});
		load.addActionListener(
			new ActionListener()
			{
				/************************************************************
				 *  !ToDo (Method description)
				 *
				 *@param  e  !ToDo (Parameter description)
				 ***********************************************************/
				public void actionPerformed(ActionEvent e)
				{
					try
					{
						File tmp = FileDialoger.promptToOpenFile()
								.getSelectedFile();
						if (tmp != null)
						{
							manager.addFile(tmp.getAbsolutePath());
						}
					}
					catch (IOException ex)
					{
						ex.printStackTrace();
					}
				}
			});
		save.addActionListener(
			new ActionListener()
			{
				/************************************************************
				 *  !ToDo (Method description)
				 *
				 *@param  e  !ToDo (Parameter description)
				 ***********************************************************/
				public void actionPerformed(ActionEvent e)
				{
					try
					{
						File tmp = FileDialoger.promptToOpenFile()
								.getSelectedFile();
						if (tmp != null)
						{
							manager.save(tmp.getAbsolutePath());
						}
					}
					catch (IOException ex)
					{
						ex.printStackTrace();
					}
				}
			});

		JPanel panel = new JPanel();
		GridBagLayout g = new GridBagLayout();
		panel.setLayout(g);
		GridBagConstraints c = new GridBagConstraints();
		c.fill = c.NONE;
		c.gridwidth = 1;
		c.gridheight = 1;
		c.gridx = 1;
		c.gridy = 1;
		g.setConstraints(add, c);
		panel.add(add);
		c.gridx = 2;
		c.gridy = 1;
		g.setConstraints(edit, c);
		panel.add(edit);
		c.gridx = 3;
		c.gridy = 1;
		g.setConstraints(delete, c);
		panel.add(delete);
		c.gridx = 2;
		c.gridy = 2;
		g.setConstraints(load, c);
		panel.add(load);
		c.gridx = 3;
		c.gridy = 2;
		g.setConstraints(save, c);
		panel.add(save);
		main.add(panel, "South");
		this.add(main);
	}
}
