/*
 * ====================================================================
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2001 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in
 * the documentation and/or other materials provided with the
 * distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 * if any, must include the following acknowledgment:
 * "This product includes software developed by the
 * Apache Software Foundation (http://www.apache.org/)."
 * Alternately, this acknowledgment may appear in the software itself,
 * if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Apache" and "Apache Software Foundation" and
 * "Apache JMeter" must not be used to endorse or promote products
 * derived from this software without prior written permission. For
 * written permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 * "Apache JMeter", nor may "Apache" appear in their name, without
 * prior written permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */
 package org.apache.jmeter.protocol.http.gui;

import javax.swing.*;
import javax.swing.border.*;
import javax.swing.table.*;
import java.awt.*;
import java.awt.event.*;
import java.io.*;

import org.apache.jmeter.protocol.http.control.*;
import org.apache.jmeter.util.JMeterUtils;
import org.apache.jmeter.gui.*;

/************************************************************
 *  Allows the user to specify if she needs cookie services, and give parameters
 *  for this service.
 *
 *@author     $Author: mstover1 $
 *@created    $Date: 2001/03/17 22:25:50 $
 *@version    $Revision: 1.6 $
 ***********************************************************/
public class CookiePanel extends JPanel implements ModelSupported
{

	CookieManager manager;

	/************************************************************
	 *  A table to show the authentication information
	 ***********************************************************/
	JTable cookieTable;
	NamePanel namePanel;

	/************************************************************
	 *  Default constructor
	 ***********************************************************/
	public CookiePanel()
	{
	}

	/************************************************************
	 *  !ToDo (Method description)
	 *
	 *@param  model  !ToDo (Parameter description)
	 ***********************************************************/
	public void setModel(Object model)
	{
		manager = (CookieManager)model;
		init();
	}

	public void updateGui()
	{
		manager.fireTableDataChanged();
		namePanel.updateGui();
	}

	/************************************************************
	 *  Gets a CookieManager to manage the file that is currently selected. Null is
	 *  returned if no file is currently selected. Null will also be returned if
	 *  there is a problem reading the file while getting the CookieManager.
	 *
	 *@return     !ToDo (Return description)
	 *@returns    A CookieManager for the current file, or null
	 ***********************************************************/
	public CookieManager getCookieMgr()
	{
		return manager;
	}

	/************************************************************
	 *  Shows the main cookie configuration panel
	 ***********************************************************/
	public void init()
	{
		this.setLayout(new VerticalLayout());
		namePanel = new NamePanel(manager);
		this.add(namePanel);
		cookieTable = new JTable(manager);
		cookieTable.setCellSelectionEnabled(false);
		cookieTable.setRowSelectionAllowed(true);
		cookieTable.setColumnSelectionAllowed(false);
		cookieTable.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);

		JPanel main = new JPanel();
		main.setLayout(new BorderLayout());

		JScrollPane scroller = new JScrollPane(cookieTable);
		JTableHeader tableHeader = cookieTable.getTableHeader();
		scroller.setColumnHeaderView(tableHeader);
		main.add(scroller);

		JButton add = new JButton("Add");
		JButton edit = new JButton("Edit");
		JButton delete = new JButton("Delete");
		//JButton close = new JButton("Close");
		JButton load = new JButton("Load");
		JButton save = new JButton("Save");
		Dimension d = delete.getPreferredSize();
		add.setPreferredSize(d);
		edit.setPreferredSize(d);
		//close.setPreferredSize(d);
		load.setPreferredSize(d);
		save.setPreferredSize(d);
		CookieUpdater updater = new CookieUpdater();
		add.addActionListener(updater);
		edit.addActionListener(updater);
		delete.addActionListener(
			new ActionListener()
			{
				/************************************************************
				 *  !ToDo (Method description)
				 *
				 *@param  e  !ToDo (Parameter description)
				 ***********************************************************/
				public void actionPerformed(ActionEvent e)
				{
					int row = cookieTable.getSelectedRow();
					if (row >= 0)
					{
						manager.remove(row);
					}
					manager.fireTableDataChanged();
				}
			});
		load.addActionListener(
			new ActionListener()
			{
				/************************************************************
				 *  !ToDo (Method description)
				 *
				 *@param  e  !ToDo (Parameter description)
				 ***********************************************************/
				public void actionPerformed(ActionEvent e)
				{
					try
					{
						File tmp = FileDialoger.promptToOpenFile()
								.getSelectedFile();
						if (tmp != null)
						{
							manager.addFile(tmp.getAbsolutePath());
						}
					}
					catch (IOException ex)
					{
						ex.printStackTrace();
					}
				}
			});

		save.addActionListener(
			new ActionListener()
			{
				/************************************************************
				 *  !ToDo (Method description)
				 *
				 *@param  e  !ToDo (Parameter description)
				 ***********************************************************/
				public void actionPerformed(ActionEvent e)
				{
					try
					{
						File tmp = FileDialoger.promptToOpenFile()
								.getSelectedFile();
						if (tmp != null)
						{
							manager.save(tmp.getAbsolutePath());
						}
					}
					catch (IOException ex)
					{
						ex.printStackTrace();
					}
				}
			});

		JPanel panel = new JPanel();
		GridBagLayout g = new GridBagLayout();
		panel.setLayout(g);
		GridBagConstraints c = new GridBagConstraints();
		c.fill = c.NONE;
		c.gridwidth = 1;
		c.gridheight = 1;
		c.gridx = 1;
		c.gridy = 1;
		g.setConstraints(add, c);
		panel.add(add);
		c.gridx = 2;
		c.gridy = 1;
		g.setConstraints(edit, c);
		panel.add(edit);
		c.gridx = 3;
		c.gridy = 1;
		g.setConstraints(delete, c);
		panel.add(delete);
		/*
		 * c.gridx = 1;
		 * c.gridy = 2;
		 * g.setConstraints(close, c);
		 * panel.add(close);
		 */
		c.gridx = 2;
		c.gridy = 2;
		g.setConstraints(load, c);
		panel.add(load);
		c.gridx = 3;
		c.gridy = 2;
		g.setConstraints(save, c);
		panel.add(save);
		main.add(panel, "South");
		this.add(main);
	}

	/************************************************************
	 *  Updates a cookie record
	 *
	 *@author     $Author: mstover1 $
	 *@created    $Date: 2001/03/17 22:25:50 $
	 *@version    $Revision: 1.6 $
	 ***********************************************************/
	class CookieUpdater implements ActionListener
	{
		int index;
		JTextField nameField = new JTextField(20);
		JTextField valueField = new JTextField(20);
		JTextField domainField = new JTextField(20);
		JTextField pathField = new JTextField(20);
		JCheckBox secureCheck = new JCheckBox("Secure");
		JTextField expiresField = new JTextField(20);
		JButton ok = new JButton("Ok");
		JButton cancel = new JButton("Cancel");

		JDialog updateDialog;

		/************************************************************
		 *  !ToDo (Constructor description)
		 ***********************************************************/
		public CookieUpdater()
		{
		}

		/************************************************************
		 *  returns the contructed panel containing the cookie record
		 *
		 *@return    !ToDo (Return description)
		 ***********************************************************/
		public JPanel getPanel()
		{
			JPanel main = new JPanel();
			GridBagLayout g = new GridBagLayout();

			main.setLayout(g);
			GridBagConstraints c = new GridBagConstraints();
			c.fill = c.BOTH;
			c.gridwidth = 1;
			c.gridheight = 1;
			JLabel nameLabel = new JLabel("Name:");
			c.gridx = 1;
			c.gridy = 1;
			g.setConstraints(nameLabel, c);
			main.add(nameLabel);
			JLabel valueLabel = new JLabel("Value:");
			c.gridx = 1;
			c.gridy = 2;
			g.setConstraints(valueLabel, c);
			main.add(valueLabel);
			JLabel domainLabel = new JLabel("Domain:");
			c.gridx = 1;
			c.gridy = 3;
			g.setConstraints(domainLabel, c);
			main.add(domainLabel);
			JLabel pathLabel = new JLabel("Path:");
			c.gridx = 1;
			c.gridy = 4;
			g.setConstraints(pathLabel, c);
			main.add(pathLabel);
			JLabel expiresLabel = new JLabel("Expiration:");
			c.gridx = 1;
			c.gridy = 6;
			g.setConstraints(expiresLabel, c);
			main.add(expiresLabel);

			c.gridwidth = 2;
			c.gridx = 1;
			c.gridy = 5;
			g.setConstraints(secureCheck, c);
			c.gridwidth = 1;
			main.add(secureCheck);

			c.gridx = 2;
			c.gridy = 1;
			g.setConstraints(nameField, c);
			main.add(nameField);
			c.gridx = 2;
			c.gridy = 2;
			g.setConstraints(valueField, c);
			main.add(valueField);
			c.gridx = 2;
			c.gridy = 3;
			g.setConstraints(domainField, c);
			main.add(domainField);
			c.gridx = 2;
			c.gridy = 4;
			g.setConstraints(pathField, c);
			main.add(pathField);
			c.gridx = 2;
			c.gridy = 6;
			g.setConstraints(expiresField, c);
			main.add(expiresField);

			JPanel buttons = new JPanel();
			ok.setPreferredSize(cancel.getPreferredSize());
			buttons.add(ok);
			buttons.add(cancel);
			c.gridwidth = 2;
			c.gridx = 1;
			c.gridy = 7;
			g.setConstraints(buttons, c);
			main.add(buttons);

			return main;
		}

		/************************************************************
		 *  !ToDo (Method description)
		 *
		 *@param  e  !ToDo (Parameter description)
		 ***********************************************************/
		public void actionPerformed(ActionEvent e)
		{
			String command = e.getActionCommand();
			boolean valid = true;
			index = -1;
			if (command.equals("Edit"))
			{
				index = cookieTable.getSelectedRow();
				if (index < 0)
				{
					valid = false;
				}
				else
				{
					Cookie c = manager.get(index);
					nameField = new JTextField(c.getName(), 20);
					valueField = new JTextField(c.getValue(), 20);
					domainField = new JTextField(c.getDomain(), 20);
					pathField = new JTextField(c.getPath(), 20);
					secureCheck = new JCheckBox("Secure", c.getSecure());
					expiresField = new JTextField(new Long(c.getExpires()).toString(), 20);
					ok = new JButton("Ok");
					cancel = new JButton("Cancel");
				}
			}
			else if (command.equals("Add"))
			{
				nameField = new JTextField(20);
				valueField = new JTextField(20);
				domainField = new JTextField(20);
				pathField = new JTextField(20);
				secureCheck = new JCheckBox("Secure");
				expiresField = new JTextField(20);
				ok = new JButton("Ok");
				cancel = new JButton("Cancel");
			}
			if (valid)
			{
				if (updateDialog != null)
				{
					updateDialog.dispose();
				}
				updateDialog = new JDialog();
				updateDialog.setSize(350, 300);

				ok.addActionListener(
					new ActionListener()
					{
						/************************************************************
						 *  !ToDo (Method description)
						 *
						 *@param  ev  !ToDo (Parameter description)
						 ***********************************************************/
						public void actionPerformed(ActionEvent ev)
						{
							int i = index;
							Cookie c = new Cookie();
							if (i >= 0)
							{
								c = manager.get(index);
							}
							c.setName(nameField.getText());
							c.setValue(valueField.getText());
							c.setDomain(domainField.getText());
							c.setPath(pathField.getText());
							c.setSecure(secureCheck.isSelected());
							try
							{
								c.setExpires(Long.parseLong(expiresField.getText()));
							}
							catch (NumberFormatException ex)
							{
								c.setExpires(0);
							}
							if (i < 0)
							{
								manager.add(c);
							}
							manager.fireTableDataChanged();
							updateDialog.dispose();
						}
					});
				cancel.addActionListener(
					new ActionListener()
					{
						/************************************************************
						 *  !ToDo (Method description)
						 *
						 *@param  ev  !ToDo (Parameter description)
						 ***********************************************************/
						public void actionPerformed(ActionEvent ev)
						{
							updateDialog.dispose();
						}
					});
				updateDialog.getContentPane().add(getPanel());
				updateDialog.show();
			}
		}
	}
}
