/*
 * ====================================================================
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2001 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in
 * the documentation and/or other materials provided with the
 * distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 * if any, must include the following acknowledgment:
 * "This product includes software developed by the
 * Apache Software Foundation (http://www.apache.org/)."
 * Alternately, this acknowledgment may appear in the software itself,
 * if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Apache" and "Apache Software Foundation" and
 * "Apache JMeter" must not be used to endorse or promote products
 * derived from this software without prior written permission. For
 * written permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 * "Apache JMeter", nor may "Apache" appear in their name, without
 * prior written permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */
 package org.apache.jmeter.reporters;

import org.apache.jmeter.gui.JMeterComponentModel;
import java.util.Collection;
import java.io.*;

import org.apache.jmeter.samplers.*;
import org.apache.jmeter.save.*;
import org.apache.jmeter.visualizers.*;
import org.apache.jmeter.util.JMeterUtils;

/**
 * Title:
 * Description:
 * Copyright:    Copyright (c) 2001
 * Company:
 * @author Michael Stover
 * @version 1.0
 */

public class Filer implements JMeterComponentModel,SampleListener,Saveable
{

	private String name;
	private FileVisualizer listener;

	private boolean verbose = true;
	 private boolean append = true;
	 private boolean open = false;
	 private String file;
	 private PrintWriter stream;

	public Filer()
	{
	}

	public void setListener(FileVisualizer l)
	{
		listener = l;
	}

	public Class getGuiClass()
	{
		return org.apache.jmeter.visualizers.FileVisualizer.class;
	}

	public boolean getAppend()
	{
		return append;
	}

	public void setAppend(boolean a)
	{
		append = a;
	}

	public void setVerbose(boolean v)
	{
		verbose = v;
	}

	public boolean getVerbose()
	{
		return verbose;
	}

	public String getName()
	{
		return name;
	}
	public void setName(String name)
	{
		this.name = name;
	}
	public Collection getAddList()
	{
		return null;
	}
	public String getClassLabel()
	{
		return "File Reporter";
	}

	public void uncompile()
	{

	}

	public Class getTagHandlerClass()
	{
		return org.apache.jmeter.save.handlers.FilerHandler.class;
	}

	public void sampleStarted(SampleEvent e)
	{
	}

	public void sampleStopped(SampleEvent e)
	{
	}

	public void sampleOccurred(SampleEvent e)
	{
		recordSample(e.getResult());
		listener.updateGui();
	}

	private void recordSample(SampleResult sampleResult)
	{
		long sample = sampleResult.getTime();
		  if (open) {
				if (verbose) {
					 stream.println(sampleResult.getValue(Sampler.SAMPLE_LABEL) + "  " + sample);
				} else {
					 stream.println(sample);
				}
		  }
	}

		 public void open(){
			try
			{
				this.stream = new PrintWriter(new BufferedOutputStream(new FileOutputStream(this.file, this.append)), false);
	if (verbose) {
		 this.stream.println("\n# Sample data created by " +
										  JMeterUtils.getJMeterProperties().getProperty("version"));
		 this.stream.println("\n#       URL                    Milliseconds\n");
	}
			}
			catch (Exception ex)
			{
				ex.printStackTrace();
			}
	this.open = true;
	 }

	 public void flush() {
		try
		{
			this.stream.flush();
		}
		catch (Exception ex)
		{
			ex.printStackTrace();
		}


	 }

	 public void close() {
	this.open = false;
	try
	{
		this.stream.flush();
	this.stream.close();
	}
	catch (Exception ex)
	{
		ex.printStackTrace();
	}


	 }

	 public String getFile()
	 {
		return file;
	 }

		  public void setFile(String file) {
	this.file = file;
	 }
}