/*

 * ====================================================================

 * The Apache Software License, Version 1.1

 *

 * Copyright (c) 2001 The Apache Software Foundation.  All rights

 * reserved.

 *

 * Redistribution and use in source and binary forms, with or without

 * modification, are permitted provided that the following conditions

 * are met:

 *

 * 1. Redistributions of source code must retain the above copyright

 * notice, this list of conditions and the following disclaimer.

 *

 * 2. Redistributions in binary form must reproduce the above copyright

 * notice, this list of conditions and the following disclaimer in

 * the documentation and/or other materials provided with the

 * distribution.

 *

 * 3. The end-user documentation included with the redistribution,

 * if any, must include the following acknowledgment:

 * "This product includes software developed by the

 * Apache Software Foundation (http://www.apache.org/)."

 * Alternately, this acknowledgment may appear in the software itself,

 * if and wherever such third-party acknowledgments normally appear.

 *

 * 4. The names "Apache" and "Apache Software Foundation" and

 * "Apache JMeter" must not be used to endorse or promote products

 * derived from this software without prior written permission. For

 * written permission, please contact apache@apache.org.

 *

 * 5. Products derived from this software may not be called "Apache",

 * "Apache JMeter", nor may "Apache" appear in their name, without

 * prior written permission of the Apache Software Foundation.

 *

 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED

 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES

 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE

 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR

 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,

 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT

 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF

 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND

 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,

 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT

 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF

 * SUCH DAMAGE.

 * ====================================================================

 *

 * This software consists of voluntary contributions made by many

 * individuals on behalf of the Apache Software Foundation.  For more

 * information on the Apache Software Foundation, please see

 * <http://www.apache.org/>.

 */





package org.apache.jmeter.visualizers;



import java.io.*;

import java.awt.*;

import java.awt.event.*;

import javax.swing.*;

import org.apache.jmeter.util.JMeterUtils;

import org.apache.jmeter.samplers.SampleResult;

import org.apache.jmeter.samplers.Sampler;

import org.apache.jmeter.gui.*;

import org.apache.jmeter.reporters.Filer;

/**

 * This class implements a visualizer that writes the samples to a file.

 *

 * @author  <a href="mailto:stefano@apache.org">Stefano Mazzocchi</a>

 * @version $Revision: 1.16 $ $Date: 2001/06/10 02:15:50 $

 */

public class FileVisualizer extends JPanel implements ActionListener,ModelSupported {



		 Filer  model;



	 JButton browseButton, openButton, flushButton, closeButton;

	 JFileChooser fileChooser;

	 JCheckBox appendCheck, verboseCheck;

	 JComboBox fileList;



	 public FileVisualizer() {

		  super();





	 }



	 private void init()

	 {

		// File panel

		  JPanel filePanel = new JPanel();

		  filePanel.setBorder(BorderFactory.createTitledBorder(BorderFactory.createEtchedBorder(), "Output File"));

		  GridBagLayout g = new GridBagLayout();

		  filePanel.setLayout(g);

		  GridBagConstraints c = new GridBagConstraints();

		  c.fill = c.BOTH;



		  fileList = new JComboBox();

		  fileList.setEditable(true);
		  if(model.getFile() != null)
		  {
			fileList.addItem(model.getFile());
			fileList.setSelectedItem(model.getFile());
		  }

		  fileList.addActionListener(this);

		  c.gridx = 0;

		  c.gridy = 0;

		  c.gridwidth = 4;

		  c.gridheight = 1;

		  c.weightx = 1.0;

		  c.weighty = 0.0;

		  c.insets = new Insets(3, 3, 3, 3);

		  g.setConstraints(fileList, c);

		  filePanel.add(fileList);



		  browseButton = new JButton("Browse");

		  browseButton.addActionListener(this);

		  browseButton.setEnabled(true);

		  c.gridwidth = 1;

		  c.gridx = 4;

		  g.setConstraints(browseButton, c);

		  filePanel.add(browseButton);



		  appendCheck = new JCheckBox("Append", model.getAppend());

		  appendCheck.addActionListener(this);

		  c.gridx = 0;

		  c.gridy = 1;

		  g.setConstraints(appendCheck, c);

		  filePanel.add(appendCheck);



		  verboseCheck = new JCheckBox("Verbose Output", model.getVerbose());

		  verboseCheck.addActionListener(this);

		  c.gridx = 1;

		  g.setConstraints(verboseCheck, c);

		  filePanel.add(verboseCheck);



		  openButton = new JButton("Open");

		  openButton.addActionListener(this);

		  openButton.setEnabled(true);

		  c.gridx = 2;

		  g.setConstraints(openButton, c);

		  filePanel.add(openButton);



		  flushButton = new JButton("Flush");

		  flushButton.addActionListener(this);

		  flushButton.setEnabled(false);

		  c.gridx = 3;

		  g.setConstraints(flushButton, c);

		  filePanel.add(flushButton);



		  closeButton = new JButton("Close");

		  closeButton.addActionListener(this);

		  closeButton.setEnabled(false);

		  c.gridx = 4;

		  g.setConstraints(closeButton, c);

		  filePanel.add(closeButton);



		  fileChooser = new JFileChooser();



		  this.add(filePanel);

	 }



	 public void setModel(Object model)

	 {

		this.model = (Filer)model;

		this.model.setListener(this);

		init();

	 }



	 public void open()

	 {

		browseButton.setEnabled(false);

		openButton.setEnabled(false);

		flushButton.setEnabled(true);

		closeButton.setEnabled(true);

		model.open();

	 }



	 public void close()

	 {

		browseButton.setEnabled(true);

		openButton.setEnabled(true);

		flushButton.setEnabled(false);

		closeButton.setEnabled(false);

		model.close();

	 }



	 public void setFile(String file)

	 {

		fileList.removeItem(file);

		fileList.addItem(file);

		fileList.getEditor().setItem(file);

		model.setFile(file);

	 }



	 public void updateGui()

	 {

	 }



	 public void actionPerformed(ActionEvent e) {

		  try {

			 JComponent c = (JComponent) e.getSource();

			 if(c == fileList) {

					 setFile((String) fileList.getSelectedItem());

				} else if (c == appendCheck) {

					 model.setAppend(appendCheck.isSelected());

				} else if (c == browseButton) {

		/*

					 int retval = fileChooser.showOpenDialog(this);

					 if (retval == JFileChooser.APPROVE_OPTION) {

						  this.file = fileChooser.getSelectedFile().toString();

		*/

		File tmp = FileDialoger.promptToOpenFile().getSelectedFile();

		if( tmp != null ) {

			 setFile(tmp.toString());

					 }

				} else if (c == openButton) {

					 open();

				} else if (c == flushButton) {

					 model.flush();

				} else if (c == closeButton) {

		close();

				} else if (c == verboseCheck) {

					 model.setVerbose(verboseCheck.isSelected());

				} else {

					 // do nothing!

				}

		  } catch (Exception ex) {

				JOptionPane.showMessageDialog(this, ex, "Error", JOptionPane.ERROR_MESSAGE);

		  }

	 }

}

